@@ -9,6 +9,7 @@ from hashlib import sha256
 
 # Refactor me
 from bson.json_util import dumps  # dumping mongob objects to string
+from bson.objectid import ObjectId
 from collections import OrderedDict
 from decimal import Decimal
 
@@ -33,6 +34,8 @@ class EWAHJSONEncoder(json.JSONEncoder):
 
         if isinstance(obj, Decimal):
             return float(obj)
+        if isinstance(obj, ObjectId):
+            return str(obj)
         # Let the base class default method raise the TypeError
         return super().default(obj)
 
@@ -126,7 +129,7 @@ class EWAHCleaner(LoggingMixin):
 
         if add_metadata:
             cleaning_steps.append(self._add_metadata)
-            self.add_metadata = add_metadata
+        self.add_metadata = add_metadata
 
         if additional_callables:
             if callable(additional_callables):
@@ -188,10 +191,13 @@ class EWAHCleaner(LoggingMixin):
 
     def clean_values(self, raw_row: dict):
         row = deepcopy(self.default_row)
-
-        while raw_row:
-            key, value = raw_row.popitem()
+        # Note: Destructive iteration using raw_row.popitem() causes a reversed order!
+        # --> create a list of tuples first and then destructively iterate over it.
+        key_value_pairs = list(raw_row.items())
+        while key_value_pairs:
+            key, value = key_value_pairs.pop(0)
             if not value is None:
+                value_type = None  # May be set during the type change below
                 if isinstance(value, str):
                     if value == "\0":
                         # This is a null value -> treat as None
@@ -201,6 +207,10 @@ class EWAHCleaner(LoggingMixin):
                         # Thus, remove it
                         value = value.replace("\x00", "")
                 elif isinstance(value, (dict, OrderedDict, list)):
+                    if isinstance(value, OrderedDict):
+                        value_type = dict
+                    else:
+                        value_type = type(value)
                     # Logic copy-pasted from legacy - TODO: Refactor this!
                     try:
                         value = json.dumps(value, cls=self.json_encoder)
@@ -213,16 +223,23 @@ class EWAHCleaner(LoggingMixin):
                 row[key] = value
 
                 # Set the fields_definition for the key
-                value_type = type(value)
+                value_type = value_type or type(value)  # set now if not done above
                 current_type_set = self.fields_definition.get(key)
                 if current_type_set:
-                    if not current_type_set == value_type:
+                    if (
+                        not current_type_set == value_type
+                        and not current_type_set == str
+                    ):
                         # TODO: make this flexible
                         # For now, default to text in case of conflict
                         self.fields_definition[key] = str
                         self.log.info(
-                            "WARNING! Data types are inconsistent. "
-                            "Affected: {0}".format(key)
+                            "\n\nWARNING! Data types are inconsistent.\n"
+                            "\tAffected field: {0}\n"
+                            "\tFirst type: {1}\n"
+                            "\tSecond type: {2}\n".format(
+                                key, str(current_type_set), str(value_type)
+                            )
                         )
                 else:
                     self.fields_definition[key] = value_type
