@@ -14,7 +14,7 @@ class EWAHConstants:
     DWH_ENGINES = [
         DWH_ENGINE_POSTGRES,
         DWH_ENGINE_SNOWFLAKE,
-        # DWH_ENGINE_BIGQUERY, To Be Implemented
+        DWH_ENGINE_BIGQUERY,
         # DWH_ENGINE_REDSHIFT, To Be Implemented
         # DWH_ENGINE_S3, To Be Implemented
         DWH_ENGINE_GS,
@@ -63,34 +63,10 @@ class EWAHConstants:
     # Query Building Constants
     QBC_FIELD_TYPE = "data_type"
 
-    QBC_FIELD_PK = "is_primary_key"
-    QBC_FIELD_HASH = "is_hash_column"
-    QBC_FIELD_GSHEET_COLNO = "column"  # Gsheet operator: position of the column
-    QBC_FIELD_CONSTRAINTS_MAPPING = {
-        DWH_ENGINE_POSTGRES: {
-            QBC_FIELD_PK: "PRIMARY KEY",
-        },
-        DWH_ENGINE_SNOWFLAKE: {
-            QBC_FIELD_PK: "PRIMARY KEY",
-        },
-        # DWH_ENGINE_BIGQUERY: {},
-        # DWH_ENGINE_REDSHIFT: {},
-        # DWH_ENGINE_S3: {},
-        DWH_ENGINE_GS: {
-            # Not applicable
-        },
-    }
-
-    """When a columns_definition is given, but a column does not have a field
-    type defined, use default as specified here. If no columns_definition is
-    given, and a field is of inconsistent data type or type does not exist
+    """If a field is of inconsistent data type or type does not exist
     in the mapping below, use inconsistent value specified here."""
-    QBC_TYPE_MAPPING_DEFAULT = "tm_default"
-    QBC_TYPE_MAPPING_INCONSISTENT = "tm_incon"
     QBC_TYPE_MAPPING = {
         DWH_ENGINE_POSTGRES: {
-            QBC_TYPE_MAPPING_DEFAULT: "text",
-            QBC_TYPE_MAPPING_INCONSISTENT: "text",
             str: "text",
             int: "bigint",
             float: "numeric",
@@ -105,8 +81,6 @@ class EWAHConstants:
             timedelta: "interval",
         },
         DWH_ENGINE_SNOWFLAKE: {
-            QBC_TYPE_MAPPING_DEFAULT: "VARCHAR",
-            QBC_TYPE_MAPPING_INCONSISTENT: "VARCHAR",
             str: "VARCHAR",
             int: "NUMBER",
             float: "NUMBER",
@@ -120,8 +94,6 @@ class EWAHConstants:
             date: "DATE",
         },
         DWH_ENGINE_BIGQUERY: {
-            QBC_TYPE_MAPPING_DEFAULT: "STRING",
-            QBC_TYPE_MAPPING_INCONSISTENT: "STRING",
             str: "STRING",
             int: "INT64",
             float: "NUMERIC",
@@ -138,8 +110,6 @@ class EWAHConstants:
         # DWH_ENGINE_REDSHIFT: {},
         # DWH_ENGINE_S3: {},
         DWH_ENGINE_GS: {  # must have these two values evaluate to True as bool
-            QBC_TYPE_MAPPING_DEFAULT: "x",
-            QBC_TYPE_MAPPING_INCONSISTENT: "x",
             # EWAH tries to dump all non-mapped types, thus map even if map is never used!
             str: "x",
             int: "x",
