@@ -16,7 +16,7 @@ class EWAHRecurlyOperator(EWAHBaseOperator):
     _CONN_TYPE = EWAHRecurlyHook.conn_type
 
     def __init__(self, resource=None, *args, **kwargs):
-        kwargs["primary_key_column_name"] = "id"
+        kwargs["primary_key"] = "id"
         resource = resource or kwargs.get("target_table_name")
         super().__init__(*args, **kwargs)
 
